@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 #ifndef _GVM_H
 #define _GVM_H
 
@@ -53,6 +55,10 @@ struct gvm_configuration {
 	
 	gboolean autopocketpc;
 	char *autopocketpc_command;
+        
+        double percent_threshold;
+        double percent_freed;
+        double percent_used;
 };
 
 /* where our settings are rooted in the gconf tree */
